==> japhar-0.04.tar.gz: japhar-0.04/include/exceptions.h <==
/* -*- Mode: C; c-file-style: "gnu" -*-
   exceptions.h -- functions for dealing with exceptions in the interpreter.
   Created: Chris Toshok <toshok@hungry.com>
 */
/*
  This file is part of Japhar, the GNU Virtual Machine for Java Bytecodes.
  Japhar is a project of The Hungry Programmers, GNU, and OryxSoft.

  Copyright (C) 1997, 1998 The Hungry Programmers

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the Free
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */

#ifndef EXCEPTIONS_H
#define EXCEPTIONS_H

#include "objects.h"
#include "interp.h"
#include "jni.h"

void interp_athrow(StackFrame *f);

void throw_exception(JNIEnv *env, obj_thunk *exception, StackFrame *f);

/*
 * This should be used by all runtime methods to throw an exception.
 * NULL == msg is accepted.
 */
void throw_Exception(JNIEnv *env, const char *exception_name, const char *msg);

#endif /* EXCEPTIONS_h */

==> japhar-0.05.tar.gz: japhar-0.05/include/exceptions.h <==
/* -*- Mode: C; c-file-style: "gnu" -*-
   exceptions.h -- functions for dealing with exceptions in the interpreter.
   Created: Chris Toshok <toshok@hungry.com>
 */
/*
  This file is part of Japhar, the GNU Virtual Machine for Java Bytecodes.
  Japhar is a project of The Hungry Programmers, GNU, and OryxSoft.

  Copyright (C) 1997, 1998 The Hungry Programmers

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */

#ifndef EXCEPTIONS_H
#define EXCEPTIONS_H

#include "objects.h"
#include "interp.h"
#include "jni.h"

void interp_athrow(StackFrame *f);

void cleanup_exception(JNIEnv *env);
void throw_exception(JNIEnv *env, japhar_obj exception, StackFrame *f);
void toplevel_exception_handler(JNIEnv *env, japhar_obj throwable_ref);

/*
 * This should be used by all runtime methods to throw an exception.
 * NULL == msg is accepted.
 */
void throw_Exception(JNIEnv *env, const char *exception_name, const char *msg);

#endif /* EXCEPTIONS_h */
